.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mer 25 dic 2013 14:04:37 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

===================================
 :mod:`sol.views` -- Pyramid views
===================================

.. automodule:: sol.views
   :members:
